# -*- coding: utf-8 -*-
'''
HTML Object Printer, HOP in short!
Helper for rendering safe html objects with ease.
'''

__author__ = u'Michał Thoma'
__author_website__ = u'http://balor.pl'
__version__ = u'1.5.2'
__website__ = u'https://github.com/balor/hop'
