# -*- coding: utf-8 -*-

import tags

#TODO: write this helper...

class Helper(object):

    def __init__(self, website_name, website_url):
        self.website_name = website_name
        self.website_url = website_url
