# -*- coding: utf-8 -*-

EMPTY = u''

URL_PROTOCOLS = [
    u'cvs://',
    u'e2k://',
    u'feed:',
    u'file://',
    u'ftp://',
    u'git://',
    u'go://',
    u'gopher://',
    u'http://',
    u'https://',
    u'imap://',
    u'irc://',
    u'ircs://',
    u'ldap://',
    u'nntp://',
    u'pop://',
    u'rmi://',
    u'rsync://',
    u'sftp://',
    u'ssh://',
    u'teamspeak://',
]

SPECIAL_URL_PROTOCOLS = [
    u'#',
    u'aim:',
    u'apt:',
    u'cid:',
    u'dav:',
    u'dns:',
    u'fax:',
    u'gg:',
    u'gtalk:',
    u'im:',
    u'mailto:',
    u'maps:',
    u'mid:',
    u'news:',
    u'skype:',
    u'tag:',
    u'tel:',
    u'telnet:',
    u'view-source:',
    u'ws:',
    u'xmpp:',
]

